==> nextcloud-10.0.2.tar.bz2: nextcloud/apps/files_external/l10n/en_GB.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Fetching request tokens failed. Verify that your app key and secret are correct.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Fetching access tokens failed. Verify that your app key and secret are correct.",
    "Please provide a valid app key and secret." : "Please provide a valid app key and secret.",
    "Step 1 failed. Exception: %s" : "Step 1 failed. Exception: %s",
    "Step 2 failed. Exception: %s" : "Step 2 failed. Exception: %s",
    "External storage" : "External storage",
    "Dropbox App Configuration" : "Dropbox App Configuration",
    "Google Drive App Configuration" : "Google Drive App Configuration",
    "Personal" : "Personal",
    "System" : "System",
    "Grant access" : "Grant access",
    "Error configuring OAuth1" : "Error configuring OAuth1",
    "Error configuring OAuth2" : "Error configuring OAuth2",
    "Generate keys" : "Generate keys",
    "Error generating key pair" : "Error generating key pair",
    "All users. Type to select user or group." : "All users. Type to select user or group.",
    "(group)" : "(group)",
    "Compatibility with Mac NFD encoding (slow)" : "Compatibility with Mac NFD encoding (slow)",
    "Admin defined" : "Admin defined",
    "Saved" : "Saved",
    "Saving..." : "Saving...",
    "Save" : "Save",
    "Empty response from the server" : "Empty response from the server",
    "Couldn't access. Please logout and login to activate this mount point" : "Couldn't access. Please logout and login to activate this mount point",
    "Couldn't get the list of external mount points: {type}" : "Couldn't get the list of external mount points: {type}",
    "There was an error with message: " : "There was an error with message: ",
    "External mount error" : "External mount error",
    "external-storage" : "external-storage",
    "Couldn't get the list of Windows network drive mount points: empty response from the server" : "Couldn't get the list of Windows network drive mount points: empty response from the server",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Some of the configured external mount points are not connected. Please click on the red row(s) for more information",
    "Please enter the credentials for the {mount} mount" : "Please enter the credentials for the {mount} mount",
    "Username" : "Username",
    "Password" : "Password",
    "Credentials saved" : "Credentials saved",
    "Credentials saving failed" : "Credentials saving failed",
    "Credentials required" : "Credentials required",
    "Storage with id \"%i\" not found" : "Storage with id \"%i\" not found",
    "Invalid backend or authentication mechanism class" : "Invalid backend or authentication mechanism class",
    "Invalid mount point" : "Invalid mount point",
    "Objectstore forbidden" : "Objectstore forbidden",
    "Invalid storage backend \"%s\"" : "Invalid storage backend \"%s\"",
    "Not permitted to use backend \"%s\"" : "Not permitted to use backend \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Not permitted to use authentication mechanism \"%s\"",
    "Unsatisfied backend parameters" : "Unsatisfied backend parameters",
    "Unsatisfied authentication mechanism parameters" : "Unsatisfied authentication mechanism parameters",
    "Insufficient data: %s" : "Insufficient data: %s",
    "%s" : "%s",
    "Storage with id \"%i\" is not user editable" : "Storage with id \"%i\" is not user editable",
    "Access key" : "Access key",
    "Secret key" : "Secret key",
    "Builtin" : "Builtin",
    "None" : "None",
    "OAuth1" : "OAuth1",
    "App key" : "App key",
    "App secret" : "App secret",
    "OAuth2" : "OAuth2",
    "Client ID" : "Client ID",
    "Client secret" : "Client secret",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Tenant name",
    "Identity endpoint URL" : "Identity endpoint URL",
    "Rackspace" : "Rackspace",
    "API key" : "API key",
    "Log-in credentials, save in database" : "Log-in credentials, save in database",
    "Username and password" : "Username and password",
    "Log-in credentials, save in session" : "Log-in credentials, save in session",
    "User entered, store in database" : "User entered, store in database",
    "RSA public key" : "RSA public key",
    "Public key" : "Public key",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Hostname",
    "Port" : "Port",
    "Region" : "Region",
    "Enable SSL" : "Enable SSL",
    "Enable Path Style" : "Enable Path Style",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Remote subfolder",
    "Secure https://" : "Secure https://",
    "Dropbox" : "Dropbox",
    "FTP" : "FTP",
    "Host" : "Host",
    "Secure ftps://" : "Secure ftps://",
    "Google Drive" : "Google Drive",
    "Local" : "Local",
    "Location" : "Location",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "SFTP with secret key login" : "SFTP with secret key login",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Share",
    "Domain" : "Domain",
    "SMB / CIFS using OC login" : "SMB / CIFS using OC login",
    "Username as share" : "Username as share",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Service name",
    "Request timeout (seconds)" : "Request timeout (seconds)",
    "No external storage configured" : "No external storage configured",
    "You can add external storages in the personal settings" : "You can add external storages in the personal settings",
    "Name" : "Name",
    "Storage type" : "Storage type",
    "Scope" : "Scope",
    "Enable encryption" : "Enable encryption",
    "Enable previews" : "Enable previews",
    "Enable sharing" : "Enable sharing",
    "Check for changes" : "Check for changes",
    "Never" : "Never",
    "Once every direct access" : "Once every direct access",
    "Folder name" : "Folder name",
    "Authentication" : "Authentication",
    "Configuration" : "Configuration",
    "Available for" : "Available for",
    "Add storage" : "Add storage",
    "Advanced settings" : "Advanced settings",
    "Delete" : "Delete",
    "Allow users to mount external storage" : "Allow users to mount external storage",
    "Allow users to mount the following external storage" : "Allow users to mount the following external storage",
    "Couldn't get the information from the ownCloud server: {code} {type}" : "Couldn't get the information from the ownCloud server: {code} {type}",
    "Global Credentials" : "Global Credentials",
    "ownCloud" : "ownCloud",
    "<b>Note:</b> " : "<b>Note:</b> ",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it.",
    "External Storage" : "External Storage"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.4.tar.bz2: nextcloud/apps/files_external/l10n/en_GB.js <==
OC.L10N.register(
    "files_external",
    {
    "External storages" : "External storages",
    "Personal" : "Personal",
    "System" : "System",
    "Grant access" : "Grant access",
    "Error configuring OAuth1" : "Error configuring OAuth1",
    "Please provide a valid app key and secret." : "Please provide a valid app key and secret.",
    "Error configuring OAuth2" : "Error configuring OAuth2",
    "Generate keys" : "Generate keys",
    "Error generating key pair" : "Error generating key pair",
    "All users. Type to select user or group." : "All users. Type to select user or group.",
    "(group)" : "(group)",
    "Compatibility with Mac NFD encoding (slow)" : "Compatibility with Mac NFD encoding (slow)",
    "Admin defined" : "Admin defined",
    "Are you sure you want to delete this external storage" : "Are you sure you want to delete this external storage",
    "Delete storage?" : "Delete storage?",
    "Saved" : "Saved",
    "Saving..." : "Saving...",
    "Save" : "Save",
    "Empty response from the server" : "Empty response from the server",
    "Couldn't access. Please log out and in again to activate this mount point" : "Couldn't access. Please log out and in again to activate this mount point",
    "Couldn't get the information from the remote server: {code} {type}" : "Couldn't get the information from the remote server: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Couldn't get the list of external mount points: {type}",
    "There was an error with message: " : "There was an error with message: ",
    "External mount error" : "External mount error",
    "external-storage" : "external-storage",
    "Couldn't fetch list of Windows network drive mount points: Empty response from server" : "Couldn't fetch list of Windows network drive mount points: Empty response from server",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Some of the configured external mount points are not connected. Please click on the red row(s) for more information",
    "Please enter the credentials for the {mount} mount" : "Please enter the credentials for the {mount} mount",
    "Username" : "Username",
    "Password" : "Password",
    "Credentials saved" : "Credentials saved",
    "Credentials saving failed" : "Credentials saving failed",
    "Credentials required" : "Credentials required",
    "Storage with ID \"%d\" not found" : "Storage with ID \"%d\" not found",
    "Invalid backend or authentication mechanism class" : "Invalid backend or authentication mechanism class",
    "Invalid mount point" : "Invalid mount point",
    "Objectstore forbidden" : "Objectstore forbidden",
    "Invalid storage backend \"%s\"" : "Invalid storage backend \"%s\"",
    "Not permitted to use backend \"%s\"" : "Not permitted to use backend \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Not permitted to use authentication mechanism \"%s\"",
    "Unsatisfied backend parameters" : "Unsatisfied backend parameters",
    "Unsatisfied authentication mechanism parameters" : "Unsatisfied authentication mechanism parameters",
    "Insufficient data: %s" : "Insufficient data: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not user editable" : "Storage with ID \"%d\" is not user editable",
    "Access key" : "Access key",
    "Secret key" : "Secret key",
    "Builtin" : "Builtin",
    "None" : "None",
    "OAuth1" : "OAuth1",
    "App key" : "App key",
    "App secret" : "App secret",
    "OAuth2" : "OAuth2",
    "Client ID" : "Client ID",
    "Client secret" : "Client secret",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Tenant name",
    "Identity endpoint URL" : "Identity endpoint URL",
    "Rackspace" : "Rackspace",
    "API key" : "API key",
    "Global credentials" : "Global credentials",
    "Log-in credentials, save in database" : "Log-in credentials, save in database",
    "Username and password" : "Username and password",
    "Log-in credentials, save in session" : "Log-in credentials, save in session",
    "User entered, store in database" : "User entered, store in database",
    "RSA public key" : "RSA public key",
    "Public key" : "Public key",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Hostname",
    "Port" : "Port",
    "Region" : "Region",
    "Enable SSL" : "Enable SSL",
    "Enable Path Style" : "Enable Path Style",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Remote subfolder",
    "Secure https://" : "Secure https://",
    "FTP" : "FTP",
    "Host" : "Host",
    "Secure ftps://" : "Secure ftps://",
    "Local" : "Local",
    "Location" : "Location",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "SFTP with secret key login" : "SFTP with secret key login",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Share",
    "Domain" : "Domain",
    "SMB / CIFS using OC login" : "SMB / CIFS using OC login",
    "Username as share" : "Username as share",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Service name",
    "Request timeout (seconds)" : "Request timeout (seconds)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it.",
    "\"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "\"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it.",
    "No external storage configured" : "No external storage configured",
    "You can add external storages in the personal settings" : "You can add external storages in the personal settings",
    "Name" : "Name",
    "Storage type" : "Storage type",
    "Scope" : "Scope",
    "Enable encryption" : "Enable encryption",
    "Enable previews" : "Enable previews",
    "Enable sharing" : "Enable sharing",
    "Check for changes" : "Check for changes",
    "Never" : "Never",
    "Once every direct access" : "Once every direct access",
    "Folder name" : "Folder name",
    "External storage" : "External storage",
    "Authentication" : "Authentication",
    "Configuration" : "Configuration",
    "Available for" : "Available for",
    "Add storage" : "Add storage",
    "Advanced settings" : "Advanced settings",
    "Delete" : "Delete",
    "Allow users to mount external storage" : "Allow users to mount external storage",
    "Allow users to mount the following external storage" : "Allow users to mount the following external storage",
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Fetching request tokens failed. Verify that your app key and secret are correct.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Fetching access tokens failed. Verify that your app key and secret are correct.",
    "Step 1 failed. Exception: %s" : "Step 1 failed. Exception: %s",
    "Step 2 failed. Exception: %s" : "Step 2 failed. Exception: %s",
    "Dropbox App Configuration" : "Dropbox App Configuration",
    "Google Drive App Configuration" : "Google Drive App Configuration",
    "Storage with id \"%i\" not found" : "Storage with id \"%i\" not found",
    "Storage with id \"%i\" is not user editable" : "Storage with id \"%i\" is not user editable",
    "Dropbox" : "Dropbox",
    "Google Drive" : "Google Drive"
},
"nplurals=2; plural=(n != 1);");
